#  Pyrogram - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-2021 Dan <https://github.com/delivrance>
#
#  This file is part of Pyrogram.
#
#  Pyrogram is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Pyrogram is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.raw.core.primitives import Int, Long, Int128, Int256, Bool, Bytes, String, Double, Vector
from pyrogram.raw.core import TLObject
from pyrogram import raw
from typing import List, Union, Any

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #


class EncryptedMessageService(TLObject):  # type: ignore
    """This object is a constructor of the base type :obj:`~pyrogram.raw.base.EncryptedMessage`.

    Details:
        - Layer: ``126``
        - ID: ``0x23734b06``

    Parameters:
        random_id: ``int`` ``64-bit``
        chat_id: ``int`` ``32-bit``
        date: ``int`` ``32-bit``
        bytes: ``bytes``
    """

    __slots__: List[str] = ["random_id", "chat_id", "date", "bytes"]

    ID = 0x23734b06
    QUALNAME = "types.EncryptedMessageService"

    def __init__(self, *, random_id: int, chat_id: int, date: int, bytes: bytes) -> None:
        self.random_id = random_id  # long
        self.chat_id = chat_id  # int
        self.date = date  # int
        self.bytes = bytes  # bytes

    @staticmethod
    def read(data: BytesIO, *args: Any) -> "EncryptedMessageService":
        # No flags
        
        random_id = Long.read(data)
        
        chat_id = Int.read(data)
        
        date = Int.read(data)
        
        bytes = Bytes.read(data)
        
        return EncryptedMessageService(random_id=random_id, chat_id=chat_id, date=date, bytes=bytes)

    def write(self) -> bytes:
        data = BytesIO()
        data.write(Int(self.ID, False))

        # No flags
        
        data.write(Long(self.random_id))
        
        data.write(Int(self.chat_id))
        
        data.write(Int(self.date))
        
        data.write(Bytes(self.bytes))
        
        return data.getvalue()



#  Pyrogram - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-2021 Dan <https://github.com/delivrance>
#
#  This file is part of Pyrogram.
#
#  Pyrogram is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Pyrogram is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.raw.core.primitives import Int, Long, Int128, Int256, Bool, Bytes, String, Double, Vector
from pyrogram.raw.core import TLObject
from pyrogram import raw
from typing import List, Union, Any

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #


class User(TLObject):  # type: ignore
    """This object is a constructor of the base type :obj:`~pyrogram.raw.base.User`.

    Details:
        - Layer: ``126``
        - ID: ``0x938458c1``

    Parameters:
        id: ``int`` ``32-bit``
        is_self (optional): ``bool``
        contact (optional): ``bool``
        mutual_contact (optional): ``bool``
        deleted (optional): ``bool``
        bot (optional): ``bool``
        bot_chat_history (optional): ``bool``
        bot_nochats (optional): ``bool``
        verified (optional): ``bool``
        restricted (optional): ``bool``
        min (optional): ``bool``
        bot_inline_geo (optional): ``bool``
        support (optional): ``bool``
        scam (optional): ``bool``
        apply_min_photo (optional): ``bool``
        fake (optional): ``bool``
        access_hash (optional): ``int`` ``64-bit``
        first_name (optional): ``str``
        last_name (optional): ``str``
        username (optional): ``str``
        phone (optional): ``str``
        photo (optional): :obj:`UserProfilePhoto <pyrogram.raw.base.UserProfilePhoto>`
        status (optional): :obj:`UserStatus <pyrogram.raw.base.UserStatus>`
        bot_info_version (optional): ``int`` ``32-bit``
        restriction_reason (optional): List of :obj:`RestrictionReason <pyrogram.raw.base.RestrictionReason>`
        bot_inline_placeholder (optional): ``str``
        lang_code (optional): ``str``

    See Also:
        This object can be returned by 4 methods:

        .. hlist::
            :columns: 2

            - :obj:`account.UpdateProfile <pyrogram.raw.functions.account.UpdateProfile>`
            - :obj:`account.UpdateUsername <pyrogram.raw.functions.account.UpdateUsername>`
            - :obj:`account.ChangePhone <pyrogram.raw.functions.account.ChangePhone>`
            - :obj:`users.GetUsers <pyrogram.raw.functions.users.GetUsers>`
    """

    __slots__: List[str] = ["id", "is_self", "contact", "mutual_contact", "deleted", "bot", "bot_chat_history", "bot_nochats", "verified", "restricted", "min", "bot_inline_geo", "support", "scam", "apply_min_photo", "fake", "access_hash", "first_name", "last_name", "username", "phone", "photo", "status", "bot_info_version", "restriction_reason", "bot_inline_placeholder", "lang_code"]

    ID = 0x938458c1
    QUALNAME = "types.User"

    def __init__(self, *, id: int, is_self: Union[None, bool] = None, contact: Union[None, bool] = None, mutual_contact: Union[None, bool] = None, deleted: Union[None, bool] = None, bot: Union[None, bool] = None, bot_chat_history: Union[None, bool] = None, bot_nochats: Union[None, bool] = None, verified: Union[None, bool] = None, restricted: Union[None, bool] = None, min: Union[None, bool] = None, bot_inline_geo: Union[None, bool] = None, support: Union[None, bool] = None, scam: Union[None, bool] = None, apply_min_photo: Union[None, bool] = None, fake: Union[None, bool] = None, access_hash: Union[None, int] = None, first_name: Union[None, str] = None, last_name: Union[None, str] = None, username: Union[None, str] = None, phone: Union[None, str] = None, photo: "raw.base.UserProfilePhoto" = None, status: "raw.base.UserStatus" = None, bot_info_version: Union[None, int] = None, restriction_reason: Union[None, List["raw.base.RestrictionReason"]] = None, bot_inline_placeholder: Union[None, str] = None, lang_code: Union[None, str] = None) -> None:
        self.id = id  # int
        self.is_self = is_self  # flags.10?true
        self.contact = contact  # flags.11?true
        self.mutual_contact = mutual_contact  # flags.12?true
        self.deleted = deleted  # flags.13?true
        self.bot = bot  # flags.14?true
        self.bot_chat_history = bot_chat_history  # flags.15?true
        self.bot_nochats = bot_nochats  # flags.16?true
        self.verified = verified  # flags.17?true
        self.restricted = restricted  # flags.18?true
        self.min = min  # flags.20?true
        self.bot_inline_geo = bot_inline_geo  # flags.21?true
        self.support = support  # flags.23?true
        self.scam = scam  # flags.24?true
        self.apply_min_photo = apply_min_photo  # flags.25?true
        self.fake = fake  # flags.26?true
        self.access_hash = access_hash  # flags.0?long
        self.first_name = first_name  # flags.1?string
        self.last_name = last_name  # flags.2?string
        self.username = username  # flags.3?string
        self.phone = phone  # flags.4?string
        self.photo = photo  # flags.5?UserProfilePhoto
        self.status = status  # flags.6?UserStatus
        self.bot_info_version = bot_info_version  # flags.14?int
        self.restriction_reason = restriction_reason  # flags.18?Vector<RestrictionReason>
        self.bot_inline_placeholder = bot_inline_placeholder  # flags.19?string
        self.lang_code = lang_code  # flags.22?string

    @staticmethod
    def read(data: BytesIO, *args: Any) -> "User":
        flags = Int.read(data)
        
        is_self = True if flags & (1 << 10) else False
        contact = True if flags & (1 << 11) else False
        mutual_contact = True if flags & (1 << 12) else False
        deleted = True if flags & (1 << 13) else False
        bot = True if flags & (1 << 14) else False
        bot_chat_history = True if flags & (1 << 15) else False
        bot_nochats = True if flags & (1 << 16) else False
        verified = True if flags & (1 << 17) else False
        restricted = True if flags & (1 << 18) else False
        min = True if flags & (1 << 20) else False
        bot_inline_geo = True if flags & (1 << 21) else False
        support = True if flags & (1 << 23) else False
        scam = True if flags & (1 << 24) else False
        apply_min_photo = True if flags & (1 << 25) else False
        fake = True if flags & (1 << 26) else False
        id = Int.read(data)
        
        access_hash = Long.read(data) if flags & (1 << 0) else None
        first_name = String.read(data) if flags & (1 << 1) else None
        last_name = String.read(data) if flags & (1 << 2) else None
        username = String.read(data) if flags & (1 << 3) else None
        phone = String.read(data) if flags & (1 << 4) else None
        photo = TLObject.read(data) if flags & (1 << 5) else None
        
        status = TLObject.read(data) if flags & (1 << 6) else None
        
        bot_info_version = Int.read(data) if flags & (1 << 14) else None
        restriction_reason = TLObject.read(data) if flags & (1 << 18) else []
        
        bot_inline_placeholder = String.read(data) if flags & (1 << 19) else None
        lang_code = String.read(data) if flags & (1 << 22) else None
        return User(id=id, is_self=is_self, contact=contact, mutual_contact=mutual_contact, deleted=deleted, bot=bot, bot_chat_history=bot_chat_history, bot_nochats=bot_nochats, verified=verified, restricted=restricted, min=min, bot_inline_geo=bot_inline_geo, support=support, scam=scam, apply_min_photo=apply_min_photo, fake=fake, access_hash=access_hash, first_name=first_name, last_name=last_name, username=username, phone=phone, photo=photo, status=status, bot_info_version=bot_info_version, restriction_reason=restriction_reason, bot_inline_placeholder=bot_inline_placeholder, lang_code=lang_code)

    def write(self) -> bytes:
        data = BytesIO()
        data.write(Int(self.ID, False))

        flags = 0
        flags |= (1 << 10) if self.is_self else 0
        flags |= (1 << 11) if self.contact else 0
        flags |= (1 << 12) if self.mutual_contact else 0
        flags |= (1 << 13) if self.deleted else 0
        flags |= (1 << 14) if self.bot else 0
        flags |= (1 << 15) if self.bot_chat_history else 0
        flags |= (1 << 16) if self.bot_nochats else 0
        flags |= (1 << 17) if self.verified else 0
        flags |= (1 << 18) if self.restricted else 0
        flags |= (1 << 20) if self.min else 0
        flags |= (1 << 21) if self.bot_inline_geo else 0
        flags |= (1 << 23) if self.support else 0
        flags |= (1 << 24) if self.scam else 0
        flags |= (1 << 25) if self.apply_min_photo else 0
        flags |= (1 << 26) if self.fake else 0
        flags |= (1 << 0) if self.access_hash is not None else 0
        flags |= (1 << 1) if self.first_name is not None else 0
        flags |= (1 << 2) if self.last_name is not None else 0
        flags |= (1 << 3) if self.username is not None else 0
        flags |= (1 << 4) if self.phone is not None else 0
        flags |= (1 << 5) if self.photo is not None else 0
        flags |= (1 << 6) if self.status is not None else 0
        flags |= (1 << 14) if self.bot_info_version is not None else 0
        flags |= (1 << 18) if self.restriction_reason is not None else 0
        flags |= (1 << 19) if self.bot_inline_placeholder is not None else 0
        flags |= (1 << 22) if self.lang_code is not None else 0
        data.write(Int(flags))
        
        data.write(Int(self.id))
        
        if self.access_hash is not None:
            data.write(Long(self.access_hash))
        
        if self.first_name is not None:
            data.write(String(self.first_name))
        
        if self.last_name is not None:
            data.write(String(self.last_name))
        
        if self.username is not None:
            data.write(String(self.username))
        
        if self.phone is not None:
            data.write(String(self.phone))
        
        if self.photo is not None:
            data.write(self.photo.write())
        
        if self.status is not None:
            data.write(self.status.write())
        
        if self.bot_info_version is not None:
            data.write(Int(self.bot_info_version))
        
        if self.restriction_reason is not None:
            data.write(Vector(self.restriction_reason))
        
        if self.bot_inline_placeholder is not None:
            data.write(String(self.bot_inline_placeholder))
        
        if self.lang_code is not None:
            data.write(String(self.lang_code))
        
        return data.getvalue()



#  Pyrogram - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-2021 Dan <https://github.com/delivrance>
#
#  This file is part of Pyrogram.
#
#  Pyrogram is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Pyrogram is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #

from typing import Union
from pyrogram import raw
from pyrogram.raw.core import TLObject

InputFileLocation = Union[raw.types.InputDocumentFileLocation, raw.types.InputEncryptedFileLocation, raw.types.InputFileLocation, raw.types.InputGroupCallStream, raw.types.InputPeerPhotoFileLocation, raw.types.InputPhotoFileLocation, raw.types.InputPhotoLegacyFileLocation, raw.types.InputSecureFileLocation, raw.types.InputStickerSetThumb, raw.types.InputTakeoutFileLocation]


# noinspection PyRedeclaration
class InputFileLocation:  # type: ignore
    """This base type has 10 constructors available.

    Constructors:
        .. hlist::
            :columns: 2

            - :obj:`InputDocumentFileLocation <pyrogram.raw.types.InputDocumentFileLocation>`
            - :obj:`InputEncryptedFileLocation <pyrogram.raw.types.InputEncryptedFileLocation>`
            - :obj:`InputFileLocation <pyrogram.raw.types.InputFileLocation>`
            - :obj:`InputGroupCallStream <pyrogram.raw.types.InputGroupCallStream>`
            - :obj:`InputPeerPhotoFileLocation <pyrogram.raw.types.InputPeerPhotoFileLocation>`
            - :obj:`InputPhotoFileLocation <pyrogram.raw.types.InputPhotoFileLocation>`
            - :obj:`InputPhotoLegacyFileLocation <pyrogram.raw.types.InputPhotoLegacyFileLocation>`
            - :obj:`InputSecureFileLocation <pyrogram.raw.types.InputSecureFileLocation>`
            - :obj:`InputStickerSetThumb <pyrogram.raw.types.InputStickerSetThumb>`
            - :obj:`InputTakeoutFileLocation <pyrogram.raw.types.InputTakeoutFileLocation>`
    """

    QUALNAME = "pyrogram.raw.base.InputFileLocation"

    def __init__(self):
        raise TypeError("Base types can only be used for type checking purposes: "
                        "you tried to use a base type instance as argument, "
                        "but you need to instantiate one of its constructors instead. "
                        "More info: https://docs.pyrogram.org/telegram/base/input-file-location")



#  Pyrogram - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-2021 Dan <https://github.com/delivrance>
#
#  This file is part of Pyrogram.
#
#  Pyrogram is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Pyrogram is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.raw.core.primitives import Int, Long, Int128, Int256, Bool, Bytes, String, Double, Vector
from pyrogram.raw.core import TLObject
from pyrogram import raw
from typing import List, Union, Any

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #


class UpdateChatParticipant(TLObject):  # type: ignore
    """This object is a constructor of the base type :obj:`~pyrogram.raw.base.Update`.

    Details:
        - Layer: ``126``
        - ID: ``0xf3b3781f``

    Parameters:
        chat_id: ``int`` ``32-bit``
        date: ``int`` ``32-bit``
        actor_id: ``int`` ``32-bit``
        user_id: ``int`` ``32-bit``
        qts: ``int`` ``32-bit``
        prev_participant (optional): :obj:`ChatParticipant <pyrogram.raw.base.ChatParticipant>`
        new_participant (optional): :obj:`ChatParticipant <pyrogram.raw.base.ChatParticipant>`
        invite (optional): :obj:`ExportedChatInvite <pyrogram.raw.base.ExportedChatInvite>`
    """

    __slots__: List[str] = ["chat_id", "date", "actor_id", "user_id", "qts", "prev_participant", "new_participant", "invite"]

    ID = 0xf3b3781f
    QUALNAME = "types.UpdateChatParticipant"

    def __init__(self, *, chat_id: int, date: int, actor_id: int, user_id: int, qts: int, prev_participant: "raw.base.ChatParticipant" = None, new_participant: "raw.base.ChatParticipant" = None, invite: "raw.base.ExportedChatInvite" = None) -> None:
        self.chat_id = chat_id  # int
        self.date = date  # int
        self.actor_id = actor_id  # int
        self.user_id = user_id  # int
        self.qts = qts  # int
        self.prev_participant = prev_participant  # flags.0?ChatParticipant
        self.new_participant = new_participant  # flags.1?ChatParticipant
        self.invite = invite  # flags.2?ExportedChatInvite

    @staticmethod
    def read(data: BytesIO, *args: Any) -> "UpdateChatParticipant":
        flags = Int.read(data)
        
        chat_id = Int.read(data)
        
        date = Int.read(data)
        
        actor_id = Int.read(data)
        
        user_id = Int.read(data)
        
        prev_participant = TLObject.read(data) if flags & (1 << 0) else None
        
        new_participant = TLObject.read(data) if flags & (1 << 1) else None
        
        invite = TLObject.read(data) if flags & (1 << 2) else None
        
        qts = Int.read(data)
        
        return UpdateChatParticipant(chat_id=chat_id, date=date, actor_id=actor_id, user_id=user_id, qts=qts, prev_participant=prev_participant, new_participant=new_participant, invite=invite)

    def write(self) -> bytes:
        data = BytesIO()
        data.write(Int(self.ID, False))

        flags = 0
        flags |= (1 << 0) if self.prev_participant is not None else 0
        flags |= (1 << 1) if self.new_participant is not None else 0
        flags |= (1 << 2) if self.invite is not None else 0
        data.write(Int(flags))
        
        data.write(Int(self.chat_id))
        
        data.write(Int(self.date))
        
        data.write(Int(self.actor_id))
        
        data.write(Int(self.user_id))
        
        if self.prev_participant is not None:
            data.write(self.prev_participant.write())
        
        if self.new_participant is not None:
            data.write(self.new_participant.write())
        
        if self.invite is not None:
            data.write(self.invite.write())
        
        data.write(Int(self.qts))
        
        return data.getvalue()



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['telecoin',
 'telecoin.venv.Lib.site-packages',
 'telecoin.venv.Lib.site-packages._distutils_hack',
 'telecoin.venv.Lib.site-packages.aiohttp',
 'telecoin.venv.Lib.site-packages.async_timeout',
 'telecoin.venv.Lib.site-packages.attr',
 'telecoin.venv.Lib.site-packages.chardet',
 'telecoin.venv.Lib.site-packages.chardet.cli',
 'telecoin.venv.Lib.site-packages.chardet.metadata',
 'telecoin.venv.Lib.site-packages.idna',
 'telecoin.venv.Lib.site-packages.multidict',
 'telecoin.venv.Lib.site-packages.pip',
 'telecoin.venv.Lib.site-packages.pip._internal',
 'telecoin.venv.Lib.site-packages.pip._internal.cli',
 'telecoin.venv.Lib.site-packages.pip._internal.commands',
 'telecoin.venv.Lib.site-packages.pip._internal.distributions',
 'telecoin.venv.Lib.site-packages.pip._internal.index',
 'telecoin.venv.Lib.site-packages.pip._internal.locations',
 'telecoin.venv.Lib.site-packages.pip._internal.metadata',
 'telecoin.venv.Lib.site-packages.pip._internal.models',
 'telecoin.venv.Lib.site-packages.pip._internal.network',
 'telecoin.venv.Lib.site-packages.pip._internal.operations',
 'telecoin.venv.Lib.site-packages.pip._internal.operations.build',
 'telecoin.venv.Lib.site-packages.pip._internal.operations.install',
 'telecoin.venv.Lib.site-packages.pip._internal.req',
 'telecoin.venv.Lib.site-packages.pip._internal.resolution',
 'telecoin.venv.Lib.site-packages.pip._internal.resolution.legacy',
 'telecoin.venv.Lib.site-packages.pip._internal.resolution.resolvelib',
 'telecoin.venv.Lib.site-packages.pip._internal.utils',
 'telecoin.venv.Lib.site-packages.pip._internal.vcs',
 'telecoin.venv.Lib.site-packages.pip._vendor',
 'telecoin.venv.Lib.site-packages.pip._vendor.cachecontrol',
 'telecoin.venv.Lib.site-packages.pip._vendor.cachecontrol.caches',
 'telecoin.venv.Lib.site-packages.pip._vendor.certifi',
 'telecoin.venv.Lib.site-packages.pip._vendor.chardet',
 'telecoin.venv.Lib.site-packages.pip._vendor.chardet.cli',
 'telecoin.venv.Lib.site-packages.pip._vendor.chardet.metadata',
 'telecoin.venv.Lib.site-packages.pip._vendor.colorama',
 'telecoin.venv.Lib.site-packages.pip._vendor.distlib',
 'telecoin.venv.Lib.site-packages.pip._vendor.distlib._backport',
 'telecoin.venv.Lib.site-packages.pip._vendor.html5lib',
 'telecoin.venv.Lib.site-packages.pip._vendor.html5lib._trie',
 'telecoin.venv.Lib.site-packages.pip._vendor.html5lib.filters',
 'telecoin.venv.Lib.site-packages.pip._vendor.html5lib.treeadapters',
 'telecoin.venv.Lib.site-packages.pip._vendor.html5lib.treebuilders',
 'telecoin.venv.Lib.site-packages.pip._vendor.html5lib.treewalkers',
 'telecoin.venv.Lib.site-packages.pip._vendor.idna',
 'telecoin.venv.Lib.site-packages.pip._vendor.msgpack',
 'telecoin.venv.Lib.site-packages.pip._vendor.packaging',
 'telecoin.venv.Lib.site-packages.pip._vendor.pep517',
 'telecoin.venv.Lib.site-packages.pip._vendor.pep517.in_process',
 'telecoin.venv.Lib.site-packages.pip._vendor.pkg_resources',
 'telecoin.venv.Lib.site-packages.pip._vendor.progress',
 'telecoin.venv.Lib.site-packages.pip._vendor.requests',
 'telecoin.venv.Lib.site-packages.pip._vendor.resolvelib',
 'telecoin.venv.Lib.site-packages.pip._vendor.resolvelib.compat',
 'telecoin.venv.Lib.site-packages.pip._vendor.tenacity',
 'telecoin.venv.Lib.site-packages.pip._vendor.toml',
 'telecoin.venv.Lib.site-packages.pip._vendor.urllib3',
 'telecoin.venv.Lib.site-packages.pip._vendor.urllib3.contrib',
 'telecoin.venv.Lib.site-packages.pip._vendor.urllib3.contrib._securetransport',
 'telecoin.venv.Lib.site-packages.pip._vendor.urllib3.packages',
 'telecoin.venv.Lib.site-packages.pip._vendor.urllib3.packages.backports',
 'telecoin.venv.Lib.site-packages.pip._vendor.urllib3.packages.ssl_match_hostname',
 'telecoin.venv.Lib.site-packages.pip._vendor.urllib3.util',
 'telecoin.venv.Lib.site-packages.pip._vendor.webencodings',
 'telecoin.venv.Lib.site-packages.pkg_resources',
 'telecoin.venv.Lib.site-packages.pkg_resources._vendor',
 'telecoin.venv.Lib.site-packages.pkg_resources._vendor.packaging',
 'telecoin.venv.Lib.site-packages.pkg_resources.extern',
 'telecoin.venv.Lib.site-packages.pkg_resources.tests.data.my-test-package-source',
 'telecoin.venv.Lib.site-packages.pyaes',
 'telecoin.venv.Lib.site-packages.pyrogram',
 'telecoin.venv.Lib.site-packages.pyrogram.connection',
 'telecoin.venv.Lib.site-packages.pyrogram.connection.transport',
 'telecoin.venv.Lib.site-packages.pyrogram.connection.transport.tcp',
 'telecoin.venv.Lib.site-packages.pyrogram.crypto',
 'telecoin.venv.Lib.site-packages.pyrogram.errors',
 'telecoin.venv.Lib.site-packages.pyrogram.errors.exceptions',
 'telecoin.venv.Lib.site-packages.pyrogram.handlers',
 'telecoin.venv.Lib.site-packages.pyrogram.methods',
 'telecoin.venv.Lib.site-packages.pyrogram.methods.advanced',
 'telecoin.venv.Lib.site-packages.pyrogram.methods.auth',
 'telecoin.venv.Lib.site-packages.pyrogram.methods.bots',
 'telecoin.venv.Lib.site-packages.pyrogram.methods.chats',
 'telecoin.venv.Lib.site-packages.pyrogram.methods.contacts',
 'telecoin.venv.Lib.site-packages.pyrogram.methods.decorators',
 'telecoin.venv.Lib.site-packages.pyrogram.methods.invite_links',
 'telecoin.venv.Lib.site-packages.pyrogram.methods.messages',
 'telecoin.venv.Lib.site-packages.pyrogram.methods.password',
 'telecoin.venv.Lib.site-packages.pyrogram.methods.users',
 'telecoin.venv.Lib.site-packages.pyrogram.methods.utilities',
 'telecoin.venv.Lib.site-packages.pyrogram.parser',
 'telecoin.venv.Lib.site-packages.pyrogram.raw',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.base',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.base.account',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.base.auth',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.base.channels',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.base.contacts',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.base.help',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.base.messages',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.base.payments',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.base.phone',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.base.photos',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.base.stats',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.base.storage',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.base.updates',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.base.upload',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.core',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.core.primitives',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.functions',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.functions.account',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.functions.auth',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.functions.bots',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.functions.channels',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.functions.contacts',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.functions.contest',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.functions.folders',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.functions.help',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.functions.langpack',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.functions.messages',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.functions.payments',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.functions.phone',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.functions.photos',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.functions.stats',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.functions.stickers',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.functions.updates',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.functions.upload',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.functions.users',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.types',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.types.account',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.types.auth',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.types.channels',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.types.contacts',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.types.help',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.types.messages',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.types.payments',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.types.phone',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.types.photos',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.types.stats',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.types.storage',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.types.updates',
 'telecoin.venv.Lib.site-packages.pyrogram.raw.types.upload',
 'telecoin.venv.Lib.site-packages.pyrogram.session',
 'telecoin.venv.Lib.site-packages.pyrogram.session.internals',
 'telecoin.venv.Lib.site-packages.pyrogram.storage',
 'telecoin.venv.Lib.site-packages.pyrogram.types',
 'telecoin.venv.Lib.site-packages.pyrogram.types.authorization',
 'telecoin.venv.Lib.site-packages.pyrogram.types.bots_and_keyboards',
 'telecoin.venv.Lib.site-packages.pyrogram.types.inline_mode',
 'telecoin.venv.Lib.site-packages.pyrogram.types.input_media',
 'telecoin.venv.Lib.site-packages.pyrogram.types.input_message_content',
 'telecoin.venv.Lib.site-packages.pyrogram.types.messages_and_media',
 'telecoin.venv.Lib.site-packages.pyrogram.types.user_and_chats',
 'telecoin.venv.Lib.site-packages.setuptools',
 'telecoin.venv.Lib.site-packages.setuptools._distutils',
 'telecoin.venv.Lib.site-packages.setuptools._distutils.command',
 'telecoin.venv.Lib.site-packages.setuptools._vendor',
 'telecoin.venv.Lib.site-packages.setuptools._vendor.more_itertools',
 'telecoin.venv.Lib.site-packages.setuptools._vendor.packaging',
 'telecoin.venv.Lib.site-packages.setuptools.command',
 'telecoin.venv.Lib.site-packages.setuptools.extern',
 'telecoin.venv.Lib.site-packages.wheel',
 'telecoin.venv.Lib.site-packages.wheel.cli',
 'telecoin.venv.Lib.site-packages.wheel.vendored',
 'telecoin.venv.Lib.site-packages.wheel.vendored.packaging',
 'telecoin.venv.Lib.site-packages.yarl',
 'telecoin.venv.Scripts']

package_data = \
{'': ['*'],
 'telecoin': ['venv/*',
              'venv/Lib/site-packages/PySocks-1.7.1.dist-info/*',
              'venv/Lib/site-packages/Pyrogram-1.2.9.dist-info/*',
              'venv/Lib/site-packages/aiohttp-3.7.4.post0.dist-info/*',
              'venv/Lib/site-packages/aiohttp/.hash/*',
              'venv/Lib/site-packages/async_lru-1.0.2.dist-info/*',
              'venv/Lib/site-packages/async_timeout-3.0.1.dist-info/*',
              'venv/Lib/site-packages/attrs-21.2.0.dist-info/*',
              'venv/Lib/site-packages/chardet-4.0.0.dist-info/*',
              'venv/Lib/site-packages/idna-3.2.dist-info/*',
              'venv/Lib/site-packages/multidict-5.1.0.dist-info/*',
              'venv/Lib/site-packages/multidict/_multilib/*',
              'venv/Lib/site-packages/pip-21.1.2.dist-info/*',
              'venv/Lib/site-packages/pyaes-1.6.1.dist-info/*',
              'venv/Lib/site-packages/setuptools-57.0.0.dist-info/*',
              'venv/Lib/site-packages/typing_extensions-3.10.0.2.dist-info/*',
              'venv/Lib/site-packages/wheel-0.36.2.dist-info/*',
              'venv/Lib/site-packages/yarl-1.6.3.dist-info/*']}

install_requires = \
['Pyrogram==1.2.9', 'aiohttp==3.7.4.post0']

setup_kwargs = {
    'name': 'telecoin',
    'version': '0.0.4',
    'description': 'Simple library to make payments via telegram bitcoin exchangers',
    'long_description': '**Slava Fisting Anal**',
    'author': 'Marple',
    'author_email': None,
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/marple-git/telecoin',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)



#  Pyrogram - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-2021 Dan <https://github.com/delivrance>
#
#  This file is part of Pyrogram.
#
#  Pyrogram is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Pyrogram is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.raw.core.primitives import Int, Long, Int128, Int256, Bool, Bytes, String, Double, Vector
from pyrogram.raw.core import TLObject
from pyrogram import raw
from typing import List, Union, Any

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #


class ChatFull(TLObject):  # type: ignore
    """This object is a constructor of the base type :obj:`~pyrogram.raw.base.ChatFull`.

    Details:
        - Layer: ``126``
        - ID: ``0x8a1e2983``

    Parameters:
        id: ``int`` ``32-bit``
        about: ``str``
        participants: :obj:`ChatParticipants <pyrogram.raw.base.ChatParticipants>`
        notify_settings: :obj:`PeerNotifySettings <pyrogram.raw.base.PeerNotifySettings>`
        can_set_username (optional): ``bool``
        has_scheduled (optional): ``bool``
        chat_photo (optional): :obj:`Photo <pyrogram.raw.base.Photo>`
        exported_invite (optional): :obj:`ExportedChatInvite <pyrogram.raw.base.ExportedChatInvite>`
        bot_info (optional): List of :obj:`BotInfo <pyrogram.raw.base.BotInfo>`
        pinned_msg_id (optional): ``int`` ``32-bit``
        folder_id (optional): ``int`` ``32-bit``
        call (optional): :obj:`InputGroupCall <pyrogram.raw.base.InputGroupCall>`
        ttl_period (optional): ``int`` ``32-bit``
        groupcall_default_join_as (optional): :obj:`Peer <pyrogram.raw.base.Peer>`
    """

    __slots__: List[str] = ["id", "about", "participants", "notify_settings", "can_set_username", "has_scheduled", "chat_photo", "exported_invite", "bot_info", "pinned_msg_id", "folder_id", "call", "ttl_period", "groupcall_default_join_as"]

    ID = 0x8a1e2983
    QUALNAME = "types.ChatFull"

    def __init__(self, *, id: int, about: str, participants: "raw.base.ChatParticipants", notify_settings: "raw.base.PeerNotifySettings", can_set_username: Union[None, bool] = None, has_scheduled: Union[None, bool] = None, chat_photo: "raw.base.Photo" = None, exported_invite: "raw.base.ExportedChatInvite" = None, bot_info: Union[None, List["raw.base.BotInfo"]] = None, pinned_msg_id: Union[None, int] = None, folder_id: Union[None, int] = None, call: "raw.base.InputGroupCall" = None, ttl_period: Union[None, int] = None, groupcall_default_join_as: "raw.base.Peer" = None) -> None:
        self.id = id  # int
        self.about = about  # string
        self.participants = participants  # ChatParticipants
        self.notify_settings = notify_settings  # PeerNotifySettings
        self.can_set_username = can_set_username  # flags.7?true
        self.has_scheduled = has_scheduled  # flags.8?true
        self.chat_photo = chat_photo  # flags.2?Photo
        self.exported_invite = exported_invite  # flags.13?ExportedChatInvite
        self.bot_info = bot_info  # flags.3?Vector<BotInfo>
        self.pinned_msg_id = pinned_msg_id  # flags.6?int
        self.folder_id = folder_id  # flags.11?int
        self.call = call  # flags.12?InputGroupCall
        self.ttl_period = ttl_period  # flags.14?int
        self.groupcall_default_join_as = groupcall_default_join_as  # flags.15?Peer

    @staticmethod
    def read(data: BytesIO, *args: Any) -> "ChatFull":
        flags = Int.read(data)
        
        can_set_username = True if flags & (1 << 7) else False
        has_scheduled = True if flags & (1 << 8) else False
        id = Int.read(data)
        
        about = String.read(data)
        
        participants = TLObject.read(data)
        
        chat_photo = TLObject.read(data) if flags & (1 << 2) else None
        
        notify_settings = TLObject.read(data)
        
        exported_invite = TLObject.read(data) if flags & (1 << 13) else None
        
        bot_info = TLObject.read(data) if flags & (1 << 3) else []
        
        pinned_msg_id = Int.read(data) if flags & (1 << 6) else None
        folder_id = Int.read(data) if flags & (1 << 11) else None
        call = TLObject.read(data) if flags & (1 << 12) else None
        
        ttl_period = Int.read(data) if flags & (1 << 14) else None
        groupcall_default_join_as = TLObject.read(data) if flags & (1 << 15) else None
        
        return ChatFull(id=id, about=about, participants=participants, notify_settings=notify_settings, can_set_username=can_set_username, has_scheduled=has_scheduled, chat_photo=chat_photo, exported_invite=exported_invite, bot_info=bot_info, pinned_msg_id=pinned_msg_id, folder_id=folder_id, call=call, ttl_period=ttl_period, groupcall_default_join_as=groupcall_default_join_as)

    def write(self) -> bytes:
        data = BytesIO()
        data.write(Int(self.ID, False))

        flags = 0
        flags |= (1 << 7) if self.can_set_username else 0
        flags |= (1 << 8) if self.has_scheduled else 0
        flags |= (1 << 2) if self.chat_photo is not None else 0
        flags |= (1 << 13) if self.exported_invite is not None else 0
        flags |= (1 << 3) if self.bot_info is not None else 0
        flags |= (1 << 6) if self.pinned_msg_id is not None else 0
        flags |= (1 << 11) if self.folder_id is not None else 0
        flags |= (1 << 12) if self.call is not None else 0
        flags |= (1 << 14) if self.ttl_period is not None else 0
        flags |= (1 << 15) if self.groupcall_default_join_as is not None else 0
        data.write(Int(flags))
        
        data.write(Int(self.id))
        
        data.write(String(self.about))
        
        data.write(self.participants.write())
        
        if self.chat_photo is not None:
            data.write(self.chat_photo.write())
        
        data.write(self.notify_settings.write())
        
        if self.exported_invite is not None:
            data.write(self.exported_invite.write())
        
        if self.bot_info is not None:
            data.write(Vector(self.bot_info))
        
        if self.pinned_msg_id is not None:
            data.write(Int(self.pinned_msg_id))
        
        if self.folder_id is not None:
            data.write(Int(self.folder_id))
        
        if self.call is not None:
            data.write(self.call.write())
        
        if self.ttl_period is not None:
            data.write(Int(self.ttl_period))
        
        if self.groupcall_default_join_as is not None:
            data.write(self.groupcall_default_join_as.write())
        
        return data.getvalue()



#  Pyrogram - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-2021 Dan <https://github.com/delivrance>
#
#  This file is part of Pyrogram.
#
#  Pyrogram is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Pyrogram is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.raw.core.primitives import Int, Long, Int128, Int256, Bool, Bytes, String, Double, Vector
from pyrogram.raw.core import TLObject
from pyrogram import raw
from typing import List, Union, Any

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #


class WallPaperSettings(TLObject):  # type: ignore
    """This object is a constructor of the base type :obj:`~pyrogram.raw.base.WallPaperSettings`.

    Details:
        - Layer: ``126``
        - ID: ``0x5086cf8``

    Parameters:
        blur (optional): ``bool``
        motion (optional): ``bool``
        background_color (optional): ``int`` ``32-bit``
        second_background_color (optional): ``int`` ``32-bit``
        intensity (optional): ``int`` ``32-bit``
        rotation (optional): ``int`` ``32-bit``
    """

    __slots__: List[str] = ["blur", "motion", "background_color", "second_background_color", "intensity", "rotation"]

    ID = 0x5086cf8
    QUALNAME = "types.WallPaperSettings"

    def __init__(self, *, blur: Union[None, bool] = None, motion: Union[None, bool] = None, background_color: Union[None, int] = None, second_background_color: Union[None, int] = None, intensity: Union[None, int] = None, rotation: Union[None, int] = None) -> None:
        self.blur = blur  # flags.1?true
        self.motion = motion  # flags.2?true
        self.background_color = background_color  # flags.0?int
        self.second_background_color = second_background_color  # flags.4?int
        self.intensity = intensity  # flags.3?int
        self.rotation = rotation  # flags.4?int

    @staticmethod
    def read(data: BytesIO, *args: Any) -> "WallPaperSettings":
        flags = Int.read(data)
        
        blur = True if flags & (1 << 1) else False
        motion = True if flags & (1 << 2) else False
        background_color = Int.read(data) if flags & (1 << 0) else None
        second_background_color = Int.read(data) if flags & (1 << 4) else None
        intensity = Int.read(data) if flags & (1 << 3) else None
        rotation = Int.read(data) if flags & (1 << 4) else None
        return WallPaperSettings(blur=blur, motion=motion, background_color=background_color, second_background_color=second_background_color, intensity=intensity, rotation=rotation)

    def write(self) -> bytes:
        data = BytesIO()
        data.write(Int(self.ID, False))

        flags = 0
        flags |= (1 << 1) if self.blur else 0
        flags |= (1 << 2) if self.motion else 0
        flags |= (1 << 0) if self.background_color is not None else 0
        flags |= (1 << 4) if self.second_background_color is not None else 0
        flags |= (1 << 3) if self.intensity is not None else 0
        flags |= (1 << 4) if self.rotation is not None else 0
        data.write(Int(flags))
        
        if self.background_color is not None:
            data.write(Int(self.background_color))
        
        if self.second_background_color is not None:
            data.write(Int(self.second_background_color))
        
        if self.intensity is not None:
            data.write(Int(self.intensity))
        
        if self.rotation is not None:
            data.write(Int(self.rotation))
        
        return data.getvalue()



#  Pyrogram - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-2021 Dan <https://github.com/delivrance>
#
#  This file is part of Pyrogram.
#
#  Pyrogram is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Pyrogram is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.raw.core.primitives import Int, Long, Int128, Int256, Bool, Bytes, String, Double, Vector
from pyrogram.raw.core import TLObject
from pyrogram import raw
from typing import List, Union, Any

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #


class TermsOfService(TLObject):  # type: ignore
    """This object is a constructor of the base type :obj:`~pyrogram.raw.base.help.TermsOfService`.

    Details:
        - Layer: ``126``
        - ID: ``0x780a0310``

    Parameters:
        id: :obj:`DataJSON <pyrogram.raw.base.DataJSON>`
        text: ``str``
        entities: List of :obj:`MessageEntity <pyrogram.raw.base.MessageEntity>`
        popup (optional): ``bool``
        min_age_confirm (optional): ``int`` ``32-bit``
    """

    __slots__: List[str] = ["id", "text", "entities", "popup", "min_age_confirm"]

    ID = 0x780a0310
    QUALNAME = "types.help.TermsOfService"

    def __init__(self, *, id: "raw.base.DataJSON", text: str, entities: List["raw.base.MessageEntity"], popup: Union[None, bool] = None, min_age_confirm: Union[None, int] = None) -> None:
        self.id = id  # DataJSON
        self.text = text  # string
        self.entities = entities  # Vector<MessageEntity>
        self.popup = popup  # flags.0?true
        self.min_age_confirm = min_age_confirm  # flags.1?int

    @staticmethod
    def read(data: BytesIO, *args: Any) -> "TermsOfService":
        flags = Int.read(data)
        
        popup = True if flags & (1 << 0) else False
        id = TLObject.read(data)
        
        text = String.read(data)
        
        entities = TLObject.read(data)
        
        min_age_confirm = Int.read(data) if flags & (1 << 1) else None
        return TermsOfService(id=id, text=text, entities=entities, popup=popup, min_age_confirm=min_age_confirm)

    def write(self) -> bytes:
        data = BytesIO()
        data.write(Int(self.ID, False))

        flags = 0
        flags |= (1 << 0) if self.popup else 0
        flags |= (1 << 1) if self.min_age_confirm is not None else 0
        data.write(Int(flags))
        
        data.write(self.id.write())
        
        data.write(String(self.text))
        
        data.write(Vector(self.entities))
        
        if self.min_age_confirm is not None:
            data.write(Int(self.min_age_confirm))
        
        return data.getvalue()



#  Pyrogram - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-2021 Dan <https://github.com/delivrance>
#
#  This file is part of Pyrogram.
#
#  Pyrogram is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Pyrogram is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.raw.core.primitives import Int, Long, Int128, Int256, Bool, Bytes, String, Double, Vector
from pyrogram.raw.core import TLObject
from pyrogram import raw
from typing import List, Union, Any

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #


class MaskCoords(TLObject):  # type: ignore
    """This object is a constructor of the base type :obj:`~pyrogram.raw.base.MaskCoords`.

    Details:
        - Layer: ``126``
        - ID: ``0xaed6dbb2``

    Parameters:
        n: ``int`` ``32-bit``
        x: ``float`` ``64-bit``
        y: ``float`` ``64-bit``
        zoom: ``float`` ``64-bit``
    """

    __slots__: List[str] = ["n", "x", "y", "zoom"]

    ID = 0xaed6dbb2
    QUALNAME = "types.MaskCoords"

    def __init__(self, *, n: int, x: float, y: float, zoom: float) -> None:
        self.n = n  # int
        self.x = x  # double
        self.y = y  # double
        self.zoom = zoom  # double

    @staticmethod
    def read(data: BytesIO, *args: Any) -> "MaskCoords":
        # No flags
        
        n = Int.read(data)
        
        x = Double.read(data)
        
        y = Double.read(data)
        
        zoom = Double.read(data)
        
        return MaskCoords(n=n, x=x, y=y, zoom=zoom)

    def write(self) -> bytes:
        data = BytesIO()
        data.write(Int(self.ID, False))

        # No flags
        
        data.write(Int(self.n))
        
        data.write(Double(self.x))
        
        data.write(Double(self.y))
        
        data.write(Double(self.zoom))
        
        return data.getvalue()



#  Pyrogram - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-2021 Dan <https://github.com/delivrance>
#
#  This file is part of Pyrogram.
#
#  Pyrogram is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Pyrogram is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.raw.core.primitives import Int, Long, Int128, Int256, Bool, Bytes, String, Double, Vector
from pyrogram.raw.core import TLObject
from pyrogram import raw
from typing import List, Union, Any

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #


class ExportChatInvite(TLObject):  # type: ignore
    """Telegram API method.

    Details:
        - Layer: ``126``
        - ID: ``0x14b9bcd7``

    Parameters:
        peer: :obj:`InputPeer <pyrogram.raw.base.InputPeer>`
        legacy_revoke_permanent (optional): ``bool``
        expire_date (optional): ``int`` ``32-bit``
        usage_limit (optional): ``int`` ``32-bit``

    Returns:
        :obj:`ExportedChatInvite <pyrogram.raw.base.ExportedChatInvite>`
    """

    __slots__: List[str] = ["peer", "legacy_revoke_permanent", "expire_date", "usage_limit"]

    ID = 0x14b9bcd7
    QUALNAME = "functions.messages.ExportChatInvite"

    def __init__(self, *, peer: "raw.base.InputPeer", legacy_revoke_permanent: Union[None, bool] = None, expire_date: Union[None, int] = None, usage_limit: Union[None, int] = None) -> None:
        self.peer = peer  # InputPeer
        self.legacy_revoke_permanent = legacy_revoke_permanent  # flags.2?true
        self.expire_date = expire_date  # flags.0?int
        self.usage_limit = usage_limit  # flags.1?int

    @staticmethod
    def read(data: BytesIO, *args: Any) -> "ExportChatInvite":
        flags = Int.read(data)
        
        legacy_revoke_permanent = True if flags & (1 << 2) else False
        peer = TLObject.read(data)
        
        expire_date = Int.read(data) if flags & (1 << 0) else None
        usage_limit = Int.read(data) if flags & (1 << 1) else None
        return ExportChatInvite(peer=peer, legacy_revoke_permanent=legacy_revoke_permanent, expire_date=expire_date, usage_limit=usage_limit)

    def write(self) -> bytes:
        data = BytesIO()
        data.write(Int(self.ID, False))

        flags = 0
        flags |= (1 << 2) if self.legacy_revoke_permanent else 0
        flags |= (1 << 0) if self.expire_date is not None else 0
        flags |= (1 << 1) if self.usage_limit is not None else 0
        data.write(Int(flags))
        
        data.write(self.peer.write())
        
        if self.expire_date is not None:
            data.write(Int(self.expire_date))
        
        if self.usage_limit is not None:
            data.write(Int(self.usage_limit))
        
        return data.getvalue()



#  Pyrogram - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-2021 Dan <https://github.com/delivrance>
#
#  This file is part of Pyrogram.
#
#  Pyrogram is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Pyrogram is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.raw.core.primitives import Int, Long, Int128, Int256, Bool, Bytes, String, Double, Vector
from pyrogram.raw.core import TLObject
from pyrogram import raw
from typing import List, Union, Any

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #


class UpdateBotInlineQuery(TLObject):  # type: ignore
    """This object is a constructor of the base type :obj:`~pyrogram.raw.base.Update`.

    Details:
        - Layer: ``126``
        - ID: ``0x3f2038db``

    Parameters:
        query_id: ``int`` ``64-bit``
        user_id: ``int`` ``32-bit``
        query: ``str``
        offset: ``str``
        geo (optional): :obj:`GeoPoint <pyrogram.raw.base.GeoPoint>`
        peer_type (optional): :obj:`InlineQueryPeerType <pyrogram.raw.base.InlineQueryPeerType>`
    """

    __slots__: List[str] = ["query_id", "user_id", "query", "offset", "geo", "peer_type"]

    ID = 0x3f2038db
    QUALNAME = "types.UpdateBotInlineQuery"

    def __init__(self, *, query_id: int, user_id: int, query: str, offset: str, geo: "raw.base.GeoPoint" = None, peer_type: "raw.base.InlineQueryPeerType" = None) -> None:
        self.query_id = query_id  # long
        self.user_id = user_id  # int
        self.query = query  # string
        self.offset = offset  # string
        self.geo = geo  # flags.0?GeoPoint
        self.peer_type = peer_type  # flags.1?InlineQueryPeerType

    @staticmethod
    def read(data: BytesIO, *args: Any) -> "UpdateBotInlineQuery":
        flags = Int.read(data)
        
        query_id = Long.read(data)
        
        user_id = Int.read(data)
        
        query = String.read(data)
        
        geo = TLObject.read(data) if flags & (1 << 0) else None
        
        peer_type = TLObject.read(data) if flags & (1 << 1) else None
        
        offset = String.read(data)
        
        return UpdateBotInlineQuery(query_id=query_id, user_id=user_id, query=query, offset=offset, geo=geo, peer_type=peer_type)

    def write(self) -> bytes:
        data = BytesIO()
        data.write(Int(self.ID, False))

        flags = 0
        flags |= (1 << 0) if self.geo is not None else 0
        flags |= (1 << 1) if self.peer_type is not None else 0
        data.write(Int(flags))
        
        data.write(Long(self.query_id))
        
        data.write(Int(self.user_id))
        
        data.write(String(self.query))
        
        if self.geo is not None:
            data.write(self.geo.write())
        
        if self.peer_type is not None:
            data.write(self.peer_type.write())
        
        data.write(String(self.offset))
        
        return data.getvalue()



#  Pyrogram - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-2021 Dan <https://github.com/delivrance>
#
#  This file is part of Pyrogram.
#
#  Pyrogram is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Pyrogram is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.raw.core.primitives import Int, Long, Int128, Int256, Bool, Bytes, String, Double, Vector
from pyrogram.raw.core import TLObject
from pyrogram import raw
from typing import List, Union, Any

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #


class ChannelAdminLogEventsFilter(TLObject):  # type: ignore
    """This object is a constructor of the base type :obj:`~pyrogram.raw.base.ChannelAdminLogEventsFilter`.

    Details:
        - Layer: ``126``
        - ID: ``0xea107ae4``

    Parameters:
        join (optional): ``bool``
        leave (optional): ``bool``
        invite (optional): ``bool``
        ban (optional): ``bool``
        unban (optional): ``bool``
        kick (optional): ``bool``
        unkick (optional): ``bool``
        promote (optional): ``bool``
        demote (optional): ``bool``
        info (optional): ``bool``
        settings (optional): ``bool``
        pinned (optional): ``bool``
        edit (optional): ``bool``
        delete (optional): ``bool``
        group_call (optional): ``bool``
        invites (optional): ``bool``
    """

    __slots__: List[str] = ["join", "leave", "invite", "ban", "unban", "kick", "unkick", "promote", "demote", "info", "settings", "pinned", "edit", "delete", "group_call", "invites"]

    ID = 0xea107ae4
    QUALNAME = "types.ChannelAdminLogEventsFilter"

    def __init__(self, *, join: Union[None, bool] = None, leave: Union[None, bool] = None, invite: Union[None, bool] = None, ban: Union[None, bool] = None, unban: Union[None, bool] = None, kick: Union[None, bool] = None, unkick: Union[None, bool] = None, promote: Union[None, bool] = None, demote: Union[None, bool] = None, info: Union[None, bool] = None, settings: Union[None, bool] = None, pinned: Union[None, bool] = None, edit: Union[None, bool] = None, delete: Union[None, bool] = None, group_call: Union[None, bool] = None, invites: Union[None, bool] = None) -> None:
        self.join = join  # flags.0?true
        self.leave = leave  # flags.1?true
        self.invite = invite  # flags.2?true
        self.ban = ban  # flags.3?true
        self.unban = unban  # flags.4?true
        self.kick = kick  # flags.5?true
        self.unkick = unkick  # flags.6?true
        self.promote = promote  # flags.7?true
        self.demote = demote  # flags.8?true
        self.info = info  # flags.9?true
        self.settings = settings  # flags.10?true
        self.pinned = pinned  # flags.11?true
        self.edit = edit  # flags.12?true
        self.delete = delete  # flags.13?true
        self.group_call = group_call  # flags.14?true
        self.invites = invites  # flags.15?true

    @staticmethod
    def read(data: BytesIO, *args: Any) -> "ChannelAdminLogEventsFilter":
        flags = Int.read(data)
        
        join = True if flags & (1 << 0) else False
        leave = True if flags & (1 << 1) else False
        invite = True if flags & (1 << 2) else False
        ban = True if flags & (1 << 3) else False
        unban = True if flags & (1 << 4) else False
        kick = True if flags & (1 << 5) else False
        unkick = True if flags & (1 << 6) else False
        promote = True if flags & (1 << 7) else False
        demote = True if flags & (1 << 8) else False
        info = True if flags & (1 << 9) else False
        settings = True if flags & (1 << 10) else False
        pinned = True if flags & (1 << 11) else False
        edit = True if flags & (1 << 12) else False
        delete = True if flags & (1 << 13) else False
        group_call = True if flags & (1 << 14) else False
        invites = True if flags & (1 << 15) else False
        return ChannelAdminLogEventsFilter(join=join, leave=leave, invite=invite, ban=ban, unban=unban, kick=kick, unkick=unkick, promote=promote, demote=demote, info=info, settings=settings, pinned=pinned, edit=edit, delete=delete, group_call=group_call, invites=invites)

    def write(self) -> bytes:
        data = BytesIO()
        data.write(Int(self.ID, False))

        flags = 0
        flags |= (1 << 0) if self.join else 0
        flags |= (1 << 1) if self.leave else 0
        flags |= (1 << 2) if self.invite else 0
        flags |= (1 << 3) if self.ban else 0
        flags |= (1 << 4) if self.unban else 0
        flags |= (1 << 5) if self.kick else 0
        flags |= (1 << 6) if self.unkick else 0
        flags |= (1 << 7) if self.promote else 0
        flags |= (1 << 8) if self.demote else 0
        flags |= (1 << 9) if self.info else 0
        flags |= (1 << 10) if self.settings else 0
        flags |= (1 << 11) if self.pinned else 0
        flags |= (1 << 12) if self.edit else 0
        flags |= (1 << 13) if self.delete else 0
        flags |= (1 << 14) if self.group_call else 0
        flags |= (1 << 15) if self.invites else 0
        data.write(Int(flags))
        
        return data.getvalue()



#  Pyrogram - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-2021 Dan <https://github.com/delivrance>
#
#  This file is part of Pyrogram.
#
#  Pyrogram is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Pyrogram is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #

from .register_device import RegisterDevice
from .unregister_device import UnregisterDevice
from .update_notify_settings import UpdateNotifySettings
from .get_notify_settings import GetNotifySettings
from .reset_notify_settings import ResetNotifySettings
from .update_profile import UpdateProfile
from .update_status import UpdateStatus
from .get_wall_papers import GetWallPapers
from .report_peer import ReportPeer
from .check_username import CheckUsername
from .update_username import UpdateUsername
from .get_privacy import GetPrivacy
from .set_privacy import SetPrivacy
from .delete_account import DeleteAccount
from .get_account_ttl import GetAccountTTL
from .set_account_ttl import SetAccountTTL
from .send_change_phone_code import SendChangePhoneCode
from .change_phone import ChangePhone
from .update_device_locked import UpdateDeviceLocked
from .get_authorizations import GetAuthorizations
from .reset_authorization import ResetAuthorization
from .get_password import GetPassword
from .get_password_settings import GetPasswordSettings
from .update_password_settings import UpdatePasswordSettings
from .send_confirm_phone_code import SendConfirmPhoneCode
from .confirm_phone import ConfirmPhone
from .get_tmp_password import GetTmpPassword
from .get_web_authorizations import GetWebAuthorizations
from .reset_web_authorization import ResetWebAuthorization
from .reset_web_authorizations import ResetWebAuthorizations
from .get_all_secure_values import GetAllSecureValues
from .get_secure_value import GetSecureValue
from .save_secure_value import SaveSecureValue
from .delete_secure_value import DeleteSecureValue
from .get_authorization_form import GetAuthorizationForm
from .accept_authorization import AcceptAuthorization
from .send_verify_phone_code import SendVerifyPhoneCode
from .verify_phone import VerifyPhone
from .send_verify_email_code import SendVerifyEmailCode
from .verify_email import VerifyEmail
from .init_takeout_session import InitTakeoutSession
from .finish_takeout_session import FinishTakeoutSession
from .confirm_password_email import ConfirmPasswordEmail
from .resend_password_email import ResendPasswordEmail
from .cancel_password_email import CancelPasswordEmail
from .get_contact_sign_up_notification import GetContactSignUpNotification
from .set_contact_sign_up_notification import SetContactSignUpNotification
from .get_notify_exceptions import GetNotifyExceptions
from .get_wall_paper import GetWallPaper
from .upload_wall_paper import UploadWallPaper
from .save_wall_paper import SaveWallPaper
from .install_wall_paper import InstallWallPaper
from .reset_wall_papers import ResetWallPapers
from .get_auto_download_settings import GetAutoDownloadSettings
from .save_auto_download_settings import SaveAutoDownloadSettings
from .upload_theme import UploadTheme
from .create_theme import CreateTheme
from .update_theme import UpdateTheme
from .save_theme import SaveTheme
from .install_theme import InstallTheme
from .get_theme import GetTheme
from .get_themes import GetThemes
from .set_content_settings import SetContentSettings
from .get_content_settings import GetContentSettings
from .get_multi_wall_papers import GetMultiWallPapers
from .get_global_privacy_settings import GetGlobalPrivacySettings
from .set_global_privacy_settings import SetGlobalPrivacySettings
from .report_profile_photo import ReportProfilePhoto



#  Pyrogram - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-2021 Dan <https://github.com/delivrance>
#
#  This file is part of Pyrogram.
#
#  Pyrogram is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  Pyrogram is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.raw.core.primitives import Int, Long, Int128, Int256, Bool, Bytes, String, Double, Vector
from pyrogram.raw.core import TLObject
from pyrogram import raw
from typing import List, Union, Any

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #


class EditMessage(TLObject):  # type: ignore
    """Telegram API method.

    Details:
        - Layer: ``126``
        - ID: ``0x48f71778``

    Parameters:
        peer: :obj:`InputPeer <pyrogram.raw.base.InputPeer>`
        id: ``int`` ``32-bit``
        no_webpage (optional): ``bool``
        message (optional): ``str``
        media (optional): :obj:`InputMedia <pyrogram.raw.base.InputMedia>`
        reply_markup (optional): :obj:`ReplyMarkup <pyrogram.raw.base.ReplyMarkup>`
        entities (optional): List of :obj:`MessageEntity <pyrogram.raw.base.MessageEntity>`
        schedule_date (optional): ``int`` ``32-bit``

    Returns:
        :obj:`Updates <pyrogram.raw.base.Updates>`
    """

    __slots__: List[str] = ["peer", "id", "no_webpage", "message", "media", "reply_markup", "entities", "schedule_date"]

    ID = 0x48f71778
    QUALNAME = "functions.messages.EditMessage"

    def __init__(self, *, peer: "raw.base.InputPeer", id: int, no_webpage: Union[None, bool] = None, message: Union[None, str] = None, media: "raw.base.InputMedia" = None, reply_markup: "raw.base.ReplyMarkup" = None, entities: Union[None, List["raw.base.MessageEntity"]] = None, schedule_date: Union[None, int] = None) -> None:
        self.peer = peer  # InputPeer
        self.id = id  # int
        self.no_webpage = no_webpage  # flags.1?true
        self.message = message  # flags.11?string
        self.media = media  # flags.14?InputMedia
        self.reply_markup = reply_markup  # flags.2?ReplyMarkup
        self.entities = entities  # flags.3?Vector<MessageEntity>
        self.schedule_date = schedule_date  # flags.15?int

    @staticmethod
    def read(data: BytesIO, *args: Any) -> "EditMessage":
        flags = Int.read(data)
        
        no_webpage = True if flags & (1 << 1) else False
        peer = TLObject.read(data)
        
        id = Int.read(data)
        
        message = String.read(data) if flags & (1 << 11) else None
        media = TLObject.read(data) if flags & (1 << 14) else None
        
        reply_markup = TLObject.read(data) if flags & (1 << 2) else None
        
        entities = TLObject.read(data) if flags & (1 << 3) else []
        
        schedule_date = Int.read(data) if flags & (1 << 15) else None
        return EditMessage(peer=peer, id=id, no_webpage=no_webpage, message=message, media=media, reply_markup=reply_markup, entities=entities, schedule_date=schedule_date)

    def write(self) -> bytes:
        data = BytesIO()
        data.write(Int(self.ID, False))

        flags = 0
        flags |= (1 << 1) if self.no_webpage else 0
        flags |= (1 << 11) if self.message is not None else 0
        flags |= (1 << 14) if self.media is not None else 0
        flags |= (1 << 2) if self.reply_markup is not None else 0
        flags |= (1 << 3) if self.entities is not None else 0
        flags |= (1 << 15) if self.schedule_date is not None else 0
        data.write(Int(flags))
        
        data.write(self.peer.write())
        
        data.write(Int(self.id))
        
        if self.message is not None:
            data.write(String(self.message))
        
        if self.media is not None:
            data.write(self.media.write())
        
        if self.reply_markup is not None:
            data.write(self.reply_markup.write())
        
        if self.entities is not None:
            data.write(Vector(self.entities))
        
        if self.schedule_date is not None:
            data.write(Int(self.schedule_date))
        
        return data.getvalue()
